@@ -210,9 +210,7 @@ class DataSetEditLayout(object):
     
     def accept_changes(self):
         """Accept changes made to widget inputs"""
-        for widget in self.widgets:
-            if widget.is_active():
-                widget.set()
+        self.update_dataitems()
 
     def setup_layout(self, items):
         """Place items on layout"""
@@ -276,10 +274,17 @@ class DataSetEditLayout(object):
         for widget in self.widgets:
             widget.set_state()
 
-    def update_widgets(self):
+    def update_dataitems(self):
+        """Refresh the content of all data items"""
+        for widget in self.widgets:
+            if widget.is_active():
+                widget.set()
+
+    def update_widgets(self, except_this_one=None):
         """Refresh the content of all widgets"""
         for widget in self.widgets:
-            widget.get()
+            if widget is not except_this_one:
+                widget.get()
         
 
 
