@@ -176,6 +176,7 @@ class Distribution(object):
         self.version = None
         self.description = None
         self.target_name = None
+        self._target_dir = None
         self.icon = None
         self.data_files = []
         self.includes = self.DEFAULT_INCLUDES
@@ -187,9 +188,23 @@ class Distribution(object):
         self.vs2008 = os.name == 'nt'
         self._py2exe_is_loaded = False
         self._pyqt4_added = False
+        # Attributes relative to cx_Freeze:
+        self.executables = []
+    
+    @property
+    def target_dir(self):
+        """Return target directory (default: 'dist')"""
+        dirname = self._target_dir
+        if dirname is None:
+            return 'dist'
+        else:
+            return dirname
+    @target_dir.setter  # analysis:ignore
+    def target_dir(self, value):
+        self._target_dir = value
         
     def setup(self, name, version, description, script,
-              target_name=None, icon=None,
+              target_name=None, target_dir=None, icon=None,
               data_files=None, includes=None, excludes=None,
               bin_includes=None, bin_excludes=None,
               bin_path_includes=None, bin_path_excludes=None, vs2008=None):
@@ -199,6 +214,7 @@ class Distribution(object):
         assert osp.isfile(script)
         self.script = script
         self.target_name = target_name
+        self.target_dir = target_dir
         self.icon = icon
         if data_files is not None:
             self.data_files += data_files
@@ -214,10 +230,12 @@ class Distribution(object):
             self.bin_path_includes += bin_path_includes
         if bin_path_excludes is not None:
             self.bin_path_excludes += bin_path_excludes
-        if self.vs2008 is None:
+        if self.vs2008 is not None:
             self.vs2008 = vs2008
         if self.vs2008:
             self.data_files += create_vs2008_data_files()
+        # cx_Freeze:
+        self.add_executable(self.script, self.target_name, icon=self.icon)
 
     def add_text_data_file(self, filename, contents):
         """Create temporary data file *filename* with *contents*
@@ -276,11 +294,15 @@ class Distribution(object):
         """Include module Matplotlib to the distribution"""
         if 'matplotlib' in self.excludes:
             self.excludes.pop(self.excludes.index('matplotlib'))
-        self.includes += ['matplotlib.numerix.ma',
-                          'matplotlib.numerix.fft',
-                          'matplotlib.numerix.linear_algebra',
-                          'matplotlib.numerix.mlab',
-                          'matplotlib.numerix.random_array']
+        try:
+            import matplotlib.numerix  # analysis:ignore
+            self.includes += ['matplotlib.numerix.ma',
+                              'matplotlib.numerix.fft',
+                              'matplotlib.numerix.linear_algebra',
+                              'matplotlib.numerix.mlab',
+                              'matplotlib.numerix.random_array']
+        except ImportError:
+            pass
         self.add_module_data_files('matplotlib', ('mpl-data', ),
                                    ('.conf', '.glade', '', '.png', '.svg',
                                     '.xpm', '.ppm', '.npy', '.afm', '.ttf'))
@@ -303,13 +325,15 @@ class Distribution(object):
                 self.add_matplotlib()
             elif module_name == 'h5py':
                 import h5py
-                for attr in ['_stub', '_sync', 'utils', '_conv', '_proxy']:
+                for attr in ['_stub', '_sync', 'utils', '_conv', '_proxy',
+                             'defs']:
                     if hasattr(h5py, attr):
                         self.includes.append('h5py.%s' % attr)
                 if self.bin_path_excludes is not None and os.name == 'nt':
                     # Specific to cx_Freeze on Windows: avoid including a zlib dll
                     # built with another version of Microsoft Visual Studio
-                    self.bin_path_excludes += [r'C:\Program Files']
+                    self.bin_path_excludes += [r'C:\Program Files',
+                                               r'C:\Program Files (x86)']
                     self.data_files.append(  # necessary for cx_Freeze only
                        ('', (osp.join(get_module_path('h5py'), 'zlib1.dll'), ))
                                            )
@@ -321,6 +345,12 @@ class Distribution(object):
                     self.add_module_data_files("rst2pdf", ("styles", ),
                                                ('.json', '.style'),
                                                copy_to_root=True)
+                if module_name == 'sphinx':
+                    import sphinx.ext
+                    for fname in os.listdir(osp.dirname(sphinx.ext.__file__)):
+                        if osp.splitext(fname)[1] == '.py':
+                            modname = 'sphinx.ext.%s' % osp.splitext(fname)[0]
+                            self.includes.append(modname)
             elif module_name == 'guidata':
                 self.add_module_data_files('guidata', ("images", ),
                                        ('.png', '.svg'), copy_to_root=False)
@@ -384,31 +414,69 @@ class Distribution(object):
             print "Adding module '%s' translation file: %s" % (module_name,
                                                osp.basename(translation_file))
 
-    def build(self, library, cleanup=True):
+    def build(self, library, cleanup=True, create_archive=None):
         """Build executable with given library.
-        Supported libraries: 'py2exe', 'cx_Freeze'"""
+
+        library:
+            * 'py2exe': deploy using the `py2exe` library
+            * 'cx_Freeze': deploy using the `cx_Freeze` library
+
+        cleanup: remove 'build/dist' directories before building distribution
+
+        create_archive (requires the executable `zip`):
+            * None or False: do nothing
+            * 'add': add target directory to a ZIP archive
+            * 'move': move target directory to a ZIP archive
+        """
         if library == 'py2exe':
-            self.build_py2exe(cleanup=cleanup)
+            self.build_py2exe(cleanup=cleanup,
+                              create_archive=create_archive)
         elif library == 'cx_Freeze':
-            self.build_cx_freeze(cleanup=cleanup)
+            self.build_cx_freeze(cleanup=cleanup,
+                                 create_archive=create_archive)
         else:
             raise RuntimeError, "Unsupported library %s" % library
+    
+    def __cleanup(self):
+        """Remove old build and dist directories"""
+        remove_dir("build")
+        if osp.isdir("dist"):
+            remove_dir("dist")
+        remove_dir(self.target_dir)
+    
+    def __create_archive(self, option):
+        """Create a ZIP archive
+
+        option:
+            * 'add': add target directory to a ZIP archive
+            * 'move': move target directory to a ZIP archive
+        """
+        name = self.target_dir
+        os.system('zip "%s.zip" -r "%s"' % (name, name))
+        if option == 'move':
+            shutil.rmtree(name)
 
     def build_py2exe(self, cleanup=True, compressed=2, optimize=2,
-                     dist_dir='dist', company_name=None, copyright=None):
+                     company_name=None, copyright=None, create_archive=None):
         """Build executable with py2exe
+
         cleanup: remove 'build/dist' directories before building distribution
+
+        create_archive (requires the executable `zip`):
+            * None or False: do nothing
+            * 'add': add target directory to a ZIP archive
+            * 'move': move target directory to a ZIP archive
         """
         from distutils.core import setup
         import py2exe  # Patching distutils -- analysis:ignore
         self._py2exe_is_loaded = True
         if cleanup:
-            remove_dir("build")
-            remove_dir(dist_dir)
+            self.__cleanup()
         sys.argv += ["py2exe"]
         options = dict(compressed=compressed, optimize=optimize,
                        includes=self.includes, excludes=self.excludes,
-                       dll_excludes=self.bin_excludes, dist_dir=dist_dir)
+                       dll_excludes=self.bin_excludes,
+                       dist_dir=self.target_dir)
         windows = dict(name=self.name, description=self.description,
                        script=self.script, icon_resources=[(0, self.icon)],
                        bitmap_resources=[], other_resources=[],
@@ -417,27 +485,44 @@ class Distribution(object):
                        company_name=company_name, copyright=copyright)
         setup(data_files=self.data_files, windows=[windows,],
               options=dict(py2exe=options))
+        if create_archive:
+            self.__create_archive(create_archive)
 
-    def build_cx_freeze(self, cleanup=True):
+    def add_executable(self, script, target_name, icon=None):
+        """Add executable to the cx_Freeze distribution
+        Not supported for py2exe"""
+        from cx_Freeze import Executable
+        base = None
+        if script.endswith('.pyw') and os.name == 'nt':
+            base = 'win32gui'
+        self.executables += [Executable(self.script, base=base, icon=self.icon,
+                                        targetName=self.target_name)]
+
+    def build_cx_freeze(self, cleanup=True, create_archive=None):
         """Build executable with cx_Freeze
-        cleanup: remove 'build' directory before building distribution"""
+
+        cleanup: remove 'build/dist' directories before building distribution
+
+        create_archive (requires the executable `zip`):
+            * None or False: do nothing
+            * 'add': add target directory to a ZIP archive
+            * 'move': move target directory to a ZIP archive
+        """
         assert not self._py2exe_is_loaded, \
                "cx_Freeze can't be executed after py2exe"
-        from cx_Freeze import setup, Executable
+        from cx_Freeze import setup
         if cleanup:
-            remove_dir("build")
-        base = None
-        if self.script.endswith('.pyw') and os.name == 'nt':
-            base = 'win32gui'
+            self.__cleanup()
         sys.argv += ["build"]
         build_exe = dict(include_files=to_include_files(self.data_files),
                          includes=self.includes, excludes=self.excludes,
                          bin_excludes=self.bin_excludes,
                          bin_includes=self.bin_includes,
                          bin_path_includes=self.bin_path_includes,
-                         bin_path_excludes=self.bin_path_excludes)
+                         bin_path_excludes=self.bin_path_excludes,
+                         build_exe=self.target_dir)
         setup(name=self.name, version=self.version,
-              description=self.description,
-              executables=[Executable(self.script, base=base, icon=self.icon,
-                                      targetName=self.target_name)],
+              description=self.description, executables=self.executables,
               options=dict(build_exe=build_exe))
+        if create_archive:
+            self.__create_archive(create_archive)
